==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/ro/mail.php <==
<?php

return array(
    'a_user_canceled' => 'Un utilizator a anulat o solicitare de element pe site',
    'a_user_requested' => 'Un utilizator a solicitat un element de pe site',
    'accessory_name' => 'Nume accesoriu:',
    'additional_notes' => 'Note Aditionale:',
    'admin_has_created' => 'Un administrator a creat un cont pentru dvs. pe: site-ul Web.',
    'asset' => 'activ:',
    'asset_name' => 'Numele activului:',
    'asset_requested' => 'Activul solicitat',
    'asset_tag' => 'Eticheta activului:',
    'assigned_to' => 'Atribuit',
    'best_regards' => 'Toate cele bune,',
    'canceled' => 'Anulat:',
    'checkin_date' => 'Checkin Data:',
    'checkout_date' => 'Verifica data:',
    'click_to_confirm' => 'Dați clic pe următorul link pentru a vă confirma: contul web:',
    'click_on_the_link_accessory' => 'Dați clic pe linkul din partea de jos pentru a confirma că ați primit accesoriul.',
    'click_on_the_link_asset' => 'Faceți clic pe linkul din partea de jos pentru a confirma că ați primit activul.',
    'Confirm_Asset_Checkin' => 'Asset checkin confirmation',
    'Confirm_Accessory_Checkin' => 'Accessory checkin confirmation',
    'Confirm_accessory_delivery' => 'Accessory delivery confirmation',
    'Confirm_license_delivery' => 'License delivery confirmation',
    'Confirm_asset_delivery' => 'Asset delivery confirmation',
    'Confirm_consumable_delivery' => 'Consumable delivery confirmation',
    'current_QTY' => 'CTA curentă',
    'Days' => 'zi',
    'days' => 'zi',
    'expecting_checkin_date' => 'Data expirării așteptate:',
    'expires' => 'expiră',
    'Expiring_Assets_Report' => 'Raportul privind expirarea activelor.',
    'Expiring_Licenses_Report' => 'Certificatul de licență expirat.',
    'hello' => 'buna',
    'hi' => 'Bună',
    'i_have_read' => 'Am citit și sunt de acord cu termenii de utilizare și am primit acest articol.',
    'item' => 'Articol:',
    'Item_Request_Canceled' => 'Cererea de solicitare a fost anulată',
    'Item_Requested' => 'Elementul solicitat',
    'link_to_update_password' => 'Faceți clic pe următorul link pentru a vă actualiza parola web:',
    'login_first_admin' => 'Conectați-vă la noua dvs. instalare Snipe-IT utilizând următoarele acreditări:',
    'login' => 'Logare:',
    'Low_Inventory_Report' => 'Raport privind inventarul redus',
    'min_QTY' => 'Cantitate min',
    'name' => 'Nume',
    'new_item_checked' => 'Un element nou a fost verificat sub numele dvs., detaliile sunt de mai jos.',
    'password' => 'Parola:',
    'password_reset' => 'Resetare parola',

    'read_the_terms' => 'Citiți termenii de utilizare de mai jos.',
    'read_the_terms_and_click' => 'Citiți termenii de utilizare de mai jos și faceți clic pe link-ul din partea de jos pentru a confirma că ați citit și sunteți de acord cu termenii de utilizare și că ați primit materialul.',
    'requested' => 'Solicitat:',
    'reset_link' => 'Parola Resetare parolă',
    'reset_password' => 'Faceți clic aici pentru a vă reseta parola:',
    'serial' => 'Serial',
    'supplier' => 'Furnizor',
    'tag' => 'Etichetă',
    'test_email' => 'Testați e-mailul de la Snipe-IT',
    'test_mail_text' => 'Acesta este un test de la Snipe-IT Asset Management System. Dacă aveți acest lucru, poșta funcționează :)',
    'the_following_item' => 'Următorul articol a fost verificat în:',
    'low_inventory_alert' => 'There is :count item that is below minimum inventory or will soon be low.|There are :count items that are below minimum inventory or will soon be low.',
    'assets_warrantee_alert' => 'There is :count asset with a warrantee expiring in the next :threshold days.|There are :count assets with warrantees expiring in the next :threshold days.',
    'license_expiring_alert' => 'There is :count license expiring in the next :threshold days.|There are :count licenses expiring in the next :threshold days.',
    'to_reset' => 'Pentru a vă reseta parola web, completați acest formular:',
    'type' => 'Tip',
    'upcoming-audits' => 'There is :count asset that is coming up for audit within :threshold days.|There are :count assets that are coming up for audit within :threshold days.',
    'user' => 'User',
    'username' => 'Username',
    'welcome' => 'Bun venit: nume',
    'welcome_to' => 'Bun venit pe: web!',
    'your_credentials' => 'Informațiile dvs. Snipe-IT',
    'Accessory_Checkin_Notification' => 'Accessory checked in',
    'Asset_Checkin_Notification' => 'Asset checked in',
    'License_Checkin_Notification' => 'License checked in',
    'Expected_Checkin_Report' => 'Expected asset checkin report',
    'Expected_Checkin_Notification' => 'Reminder: :name checkin deadline approaching',
    'Expected_Checkin_Date' => 'An asset checked out to you is due to be checked back in on :date',
    'your_assets' => 'View Your Assets'
);

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/ro/mail.php <==
<?php

return [
    'a_user_canceled' => 'Un utilizator a anulat o solicitare de element pe site',
    'a_user_requested' => 'Un utilizator a solicitat un element de pe site',
    'accessory_name' => 'Nume accesoriu:',
    'additional_notes' => 'Note Aditionale:',
    'admin_has_created' => 'Un administrator a creat un cont pentru dvs. pe: site-ul Web.',
    'asset' => 'activ:',
    'asset_name' => 'Numele activului:',
    'asset_requested' => 'Activul solicitat',
    'asset_tag' => 'Asset Tag',
    'assigned_to' => 'Atribuit',
    'best_regards' => 'Toate cele bune,',
    'canceled' => 'Anulat:',
    'checkin_date' => 'Checkin Data:',
    'checkout_date' => 'Verifica data:',
    'click_to_confirm' => 'Dați clic pe următorul link pentru a vă confirma: contul web:',
    'click_on_the_link_accessory' => 'Dați clic pe linkul din partea de jos pentru a confirma că ați primit accesoriul.',
    'click_on_the_link_asset' => 'Faceți clic pe linkul din partea de jos pentru a confirma că ați primit activul.',
    'Confirm_Asset_Checkin' => 'Asset checkin confirmation',
    'Confirm_Accessory_Checkin' => 'Accessory checkin confirmation',
    'Confirm_accessory_delivery' => 'Accessory delivery confirmation',
    'Confirm_license_delivery' => 'License delivery confirmation',
    'Confirm_asset_delivery' => 'Asset delivery confirmation',
    'Confirm_consumable_delivery' => 'Consumable delivery confirmation',
    'current_QTY' => 'CTA curentă',
    'Days' => 'zi',
    'days' => 'zi',
    'expecting_checkin_date' => 'Data expirării așteptate:',
    'expires' => 'expiră',
    'Expiring_Assets_Report' => 'Raportul privind expirarea activelor.',
    'Expiring_Licenses_Report' => 'Certificatul de licență expirat.',
    'hello' => 'buna',
    'hi' => 'Bună',
    'i_have_read' => 'Am citit și sunt de acord cu termenii de utilizare și am primit acest articol.',
    'item' => 'Articol:',
    'Item_Request_Canceled' => 'Cererea de solicitare a fost anulată',
    'Item_Requested' => 'Elementul solicitat',
    'link_to_update_password' => 'Faceți clic pe următorul link pentru a vă actualiza parola web:',
    'login_first_admin' => 'Conectați-vă la noua dvs. instalare Snipe-IT utilizând următoarele acreditări:',
    'login' => 'Logare:',
    'Low_Inventory_Report' => 'Raport privind inventarul redus',
    'min_QTY' => 'Cantitate min',
    'name' => 'Nume',
    'new_item_checked' => 'Un element nou a fost verificat sub numele dvs., detaliile sunt de mai jos.',
    'password' => 'Parola:',
    'password_reset' => 'Resetare parola',

    'read_the_terms' => 'Citiți termenii de utilizare de mai jos.',
    'read_the_terms_and_click' => 'Citiți termenii de utilizare de mai jos și faceți clic pe link-ul din partea de jos pentru a confirma că ați citit și sunteți de acord cu termenii de utilizare și că ați primit materialul.',
    'requested' => 'Solicitat:',
    'reset_link' => 'Parola Resetare parolă',
    'reset_password' => 'Faceți clic aici pentru a vă reseta parola:',
    'serial' => 'Serial',
    'supplier' => 'Furnizor',
    'tag' => 'Etichetă',
    'test_email' => 'Testați e-mailul de la Snipe-IT',
    'test_mail_text' => 'Acesta este un test de la Snipe-IT Asset Management System. Dacă aveți acest lucru, poșta funcționează :)',
    'the_following_item' => 'Următorul articol a fost verificat în:',
    'low_inventory_alert' => 'There is :count item that is below minimum inventory or will soon be low.|There are :count items that are below minimum inventory or will soon be low.',
    'assets_warrantee_alert' => 'There is :count asset with a warranty expiring in the next :threshold days.|There are :count assets with warranties expiring in the next :threshold days.',
    'license_expiring_alert' => 'There is :count license expiring in the next :threshold days.|There are :count licenses expiring in the next :threshold days.',
    'to_reset' => 'Pentru a vă reseta parola web, completați acest formular:',
    'type' => 'Tip',
    'upcoming-audits' => 'There is :count asset that is coming up for audit within :threshold days.|There are :count assets that are coming up for audit within :threshold days.',
    'user' => 'User',
    'username' => 'Username',
    'welcome' => 'Bun venit: nume',
    'welcome_to' => 'Bun venit pe: web!',
    'your_credentials' => 'Informațiile dvs. Snipe-IT',
    'Accessory_Checkin_Notification' => 'Accessory checked in',
    'Asset_Checkin_Notification' => 'Asset checked in',
    'License_Checkin_Notification' => 'License checked in',
    'Expected_Checkin_Report' => 'Expected asset checkin report',
    'Expected_Checkin_Notification' => 'Reminder: :name checkin deadline approaching',
    'Expected_Checkin_Date' => 'An asset checked out to you is due to be checked back in on :date',
    'your_assets' => 'View Your Assets',
];
